summaryrefslogtreecommitdiffstats
path: root/sbin/newfs_msdos/newfs_msdos.c
diff options
context:
space:
mode:
authortrhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
committertrhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
commit136be46680c6e4a18cc827da991d4f9a0de29cba (patch)
treeb5ee0aba66633a4e0e47097e4f383c253a87887a /sbin/newfs_msdos/newfs_msdos.c
parent9618da3e35435c433d8086d65af15f716ffe32ec (diff)
downloadFreeBSD-src-136be46680c6e4a18cc827da991d4f9a0de29cba.zip
FreeBSD-src-136be46680c6e4a18cc827da991d4f9a0de29cba.tar.gz
s/filesystem/file system/g as discussed on -developers
Diffstat (limited to 'sbin/newfs_msdos/newfs_msdos.c')
-rw-r--r--sbin/newfs_msdos/newfs_msdos.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/sbin/newfs_msdos/newfs_msdos.c b/sbin/newfs_msdos/newfs_msdos.c
index c0fd131..d0085f7 100644
--- a/sbin/newfs_msdos/newfs_msdos.c
+++ b/sbin/newfs_msdos/newfs_msdos.c
@@ -116,9 +116,9 @@ struct bsbpb {
struct bsxbpb {
u_int8_t bspf[4]; /* big sectors per FAT */
u_int8_t xflg[2]; /* FAT control flags */
- u_int8_t vers[2]; /* filesystem version */
+ u_int8_t vers[2]; /* file system version */
u_int8_t rdcl[4]; /* root directory start cluster */
- u_int8_t infs[2]; /* filesystem info sector */
+ u_int8_t infs[2]; /* file system info sector */
u_int8_t bkbs[2]; /* backup boot sector */
u_int8_t rsvd[12]; /* reserved */
};
@@ -129,7 +129,7 @@ struct bsx {
u_int8_t sig; /* extended boot signature */
u_int8_t volid[4]; /* volume ID number */
u_int8_t label[11]; /* volume label */
- u_int8_t type[8]; /* filesystem type */
+ u_int8_t type[8]; /* file system type */
};
struct de {
@@ -157,7 +157,7 @@ struct bpb {
u_int bsec; /* big total sectors */
u_int bspf; /* big sectors per FAT */
u_int rdcl; /* root directory start cluster */
- u_int infs; /* filesystem info sector */
+ u_int infs; /* file system info sector */
u_int bkbs; /* backup boot sector */
};
@@ -222,7 +222,7 @@ static void setstr(u_int8_t *, const char *, size_t);
static void usage(void);
/*
* Construct a FAT12, FAT16, or FAT32 filesystem.
*/
int
main(int argc, char *argv[])
@@ -324,7 +324,7 @@ main(int argc, char *argv[])
opt_r = argto2(optarg, 1, "reserved sectors");
break;
case 's':
- opt_s = argto4(optarg, 1, "filesystem size");
+ opt_s = argto4(optarg, 1, "file system size");
break;
case 'u':
opt_u = argto2(optarg, 1, "sectors/track");
@@ -502,7 +502,7 @@ main(int argc, char *argv[])
x1 = bpb.res + rds;
x = bpb.bspf ? bpb.bspf : 1;
if (x1 + (u_int64_t)x * bpb.nft > bpb.bsec)
- errx(1, "meta data exceeds filesystem size");
+ errx(1, "meta data exceeds file system size");
x1 += x * bpb.nft;
x = (u_int64_t)(bpb.bsec - x1) * bpb.bps * NPB /
(bpb.spc * bpb.bps * NPB + fat / BPN * bpb.nft);
@@ -517,7 +517,7 @@ main(int argc, char *argv[])
if (cls > x)
cls = x;
if (bpb.bspf < x2)
- warnx("warning: sectors/FAT limits filesystem to %u clusters",
+ warnx("warning: sectors/FAT limits file system to %u clusters",
cls);
if (cls < mincls(fat))
errx(1, "%u clusters too few clusters for FAT%u, need %u", cls, fat,
@@ -525,7 +525,7 @@ main(int argc, char *argv[])
if (cls > maxcls(fat)) {
cls = maxcls(fat);
bpb.bsec = x1 + (cls + 1) * bpb.spc - 1;
- warnx("warning: FAT type limits filesystem to %u sectors",
+ warnx("warning: FAT type limits file system to %u sectors",
bpb.bsec);
}
printf("%s: %u sector%s in %u FAT%u cluster%s "
@@ -660,7 +660,7 @@ main(int argc, char *argv[])
}
/*
* Exit with error if filesystem is mounted.
*/
static void
check_mounted(const char *fname, mode_t mode)
@@ -904,7 +904,7 @@ usage(void)
fprintf(stderr,
"usage: newfs_msdos [ -options ] special [disktype]\n");
fprintf(stderr, "where the options are:\n");
- fprintf(stderr, "\t-N don't create filesystem: "
+ fprintf(stderr, "\t-N don't create file system: "
"just print out parameters\n");
fprintf(stderr, "\t-B get bootstrap from file\n");
fprintf(stderr, "\t-F FAT type (12, 16, or 32)\n");
@@ -918,13 +918,13 @@ usage(void)
fprintf(stderr, "\t-e root directory entries\n");
fprintf(stderr, "\t-f standard format\n");
fprintf(stderr, "\t-h drive heads\n");
- fprintf(stderr, "\t-i filesystem info sector\n");
+ fprintf(stderr, "\t-i file system info sector\n");
fprintf(stderr, "\t-k backup boot sector\n");
fprintf(stderr, "\t-m media descriptor\n");
fprintf(stderr, "\t-n number of FATs\n");
fprintf(stderr, "\t-o hidden sectors\n");
fprintf(stderr, "\t-r reserved sectors\n");
- fprintf(stderr, "\t-s filesystem size (sectors)\n");
+ fprintf(stderr, "\t-s file system size (sectors)\n");
fprintf(stderr, "\t-u sectors/track\n");
exit(1);
}
@@ -222,7 +222,7 @@ static void setstr(u_int8_t *, const char *, size_t);
static void usage(void);
/*
- * Construct a FAT12, FAT16, or FAT32 filesystem.
+ * Construct a FAT12, FAT16, or FAT32 file system.
*/
int
@@ -660,7 +660,7 @@ main(int argc, char *argv[])
}
/*
- * Exit with error if filesystem is mounted.
+ * Exit with error if file system is mounted.
*/
static void
OpenPOWER on IntegriCloud